#
# spec file for package maven-install-plugin
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global base_ver 3.0.0
%global milestone M1
%bcond_with tests
Name:           maven-install-plugin
Version:        %{base_ver}~%{milestone}
Release:        150200.3.4.3
Summary:        Maven Install Plugin
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://maven.apache.org/plugins/maven-install-plugin
Source0:        https://repo1.maven.org/maven2/org/apache/maven/plugins/%{name}/%{base_ver}-%{milestone}/%{name}-%{base_ver}-%{milestone}-source-release.zip
Patch0:         0001-MINSTALL-143-Remove-a-lot-of-checksum-related-dead-c.patch
Patch1:         0002-MINSTALL-171-Update-plugin-requires-Maven-3.2.5.patch
Patch2:         0003-Fix-tests-with-modular-javas.patch
Patch3:         0004-Fix-tests-with-maven-resolver-1.7.3.patch
BuildRequires:  fdupes
BuildRequires:  java-devel >= 1.8
BuildRequires:  maven-local
BuildRequires:  unzip
BuildRequires:  mvn(org.apache.maven.plugin-tools:maven-plugin-annotations)
BuildRequires:  mvn(org.apache.maven.plugins:maven-plugin-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-plugins:pom:)
BuildRequires:  mvn(org.apache.maven.shared:maven-artifact-transfer)
BuildRequires:  mvn(org.apache.maven:maven-artifact)
BuildRequires:  mvn(org.apache.maven:maven-plugin-api)
BuildRequires:  mvn(org.slf4j:slf4j-api)
BuildArch:      noarch
%if %{with tests}
BuildRequires:  mvn(junit:junit)
BuildRequires:  mvn(org.apache.maven.plugin-testing:maven-plugin-testing-harness)
BuildRequires:  mvn(org.apache.maven:maven-compat)
BuildRequires:  mvn(org.apache.maven:maven-core)
BuildRequires:  mvn(org.apache.maven:maven-model)
BuildRequires:  mvn(org.eclipse.aether:aether-api)
BuildRequires:  mvn(org.eclipse.aether:aether-impl) >= 1.7
BuildRequires:  mvn(org.eclipse.aether:aether-util)
BuildRequires:  mvn(org.mockito:mockito-core)
BuildRequires:  mvn(org.slf4j:slf4j-nop)
%endif

%description
Copies the project artifacts to the user's local repository.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Documentation/HTML

%description javadoc
API documentation for %{name}.

%prep
%setup -q -n %{name}-%{base_ver}-%{milestone}
%autopatch -p1

%build
%{mvn_build} \
%if %{without tests}
    -f \
%endif
    -- \
%if %{?pkg_vcmp:%pkg_vcmp java-devel >= 9}%{!?pkg_vcmp:0}
    -Dmaven.compiler.release=8 \
%endif
    -Dsource=8

%install
%mvn_install
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%license LICENSE
%doc NOTICE

%files javadoc -f .mfiles-javadoc
%license LICENSE
%doc NOTICE

%changelog
* Wed May 11 2022 fstrba@suse.com
- Upgrade to upstream verson 3.0.0 milestone M1
  * Bugs:
    + MINSTALL-121: The packaging property should not be used for
    the file extension
    + MINSTALL-130: Remove link to non-existing Codehaus wiki
  * Improvements:
    + MINSTALL-110: install-file should also install bundled
    pom.xml from artifact.
    + MINSTALL-114: Plugin shouldn’t depend on maven-compat
    dependency
    + MINSTALL-118: MavenProject with only attachments must have
    packaging “pom”
    + MINSTALL-124: Remove hard code version for
    maven-invoker-plugin
    + MINSTALL-128: Replace usage of the deprecated ArtifactFactory
    + MINSTALL-134: Remove checksum generation
    + MINSTALL-136: Removed unused dependency
    + MINSTALL-143: Move checksum generation from install to deploy
    plugin
  * Tasks:
    + MINSTALL-129: Use released version of maven-artifact-transfer
    + MINSTALL-131: Rename package to org.apache.maven.plugins
    + MINSTALL-145: Remove unused dependencies in pom
    + MINSTALL-148: Document change about createChecksums
    + MINSTALL-149: Remove updateReleaseInfo parameter
    + MINSTALL-150: Lift JDK minimum to JDK 7
  * Dependency upgrades:
    + MINSTALL-109: Update version of plexus-utils to 3.0.18
    + MINSTALL-111: Upgrade to maven-plugins parent version 27
    + MINSTALL-112: Upgrade maven-plugin-testing-harness to 1.3
    + MINSTALL-113: Upgrade maven-shared-utils to 0.7
    + MINSTALL-117: Upgrade maven-shared-utils to 3.0.0
    + MINSTALL-122: Upgrade maven-shared-components parent to
    version 30
    + MINSTALL-123: Upgrade maven-shared-utils to 3.0.1
    + MINSTALL-125: Upgrade of commons-io to 2.5.
    + MINSTALL-127: Upgrade maven-shared-utils to 3.1.0
    + MINSTALL-137: Upgrade maven-artifact-transfer to version 0.9.1
    + MINSTALL-140: maven-shared-utils 3.1.0 to 3.2.0
    + MINSTALL-141: plexus-utils 3.0.24 to 3.1.0
    + MINSTALL-142: Upgrade parent to 31
    + MINSTALL-144: Upgrade mave-surefire/failsafe-plugin 2.21.0
    + MINSTALL-146: Upgrade maven-plugin parent to version 32
    + MINSTALL-147: Upgrade JUnit to 4.12
- Added patches:
  * 0001-MINSTALL-143-Remove-a-lot-of-checksum-related-dead-c.patch
  * 0002-MINSTALL-171-Update-plugin-requires-Maven-3.2.5.patch
    + Backport upstream fixes to avoid the org.sonatype.aether
    dependencies
  * 0003-Fix-tests-with-modular-javas.patch
    + Add a maven profile to open needed modules to unnamed module
    + Fixes tests with Java 17
  * 0004-Fix-tests-with-maven-resolver-1.7.3.patch
    + maven-resolver 1.7.x had an incompatible change
    + This fix allows us to use the maven-resolver 1.7.3
* Tue Mar 22 2022 fstrba@suse.com
- Build with java source and target levels 8
* Sun Nov 24 2019 fstrba@suse.com
- Specify maven.compiler.release to fix build with jdk9+ and newer
  maven-javadoc-plugin
* Fri Apr  5 2019 fstrba@suse.com
- Initial packaging of maven-install-plugin 2.5.2
